import processing.serial.*;     // import the Processing serial library
Serial myPort;                  // The serial port

float xPos;   // position of platform
boolean shoot = false;
float shotPos=0;
boolean oneShot =true;

void setup() {
  size(640, 480);

  // List all the available serial ports
  println(Serial.list());

  // Change the 0 to the appropriate number of the serial port
  // that your microcontroller is attached to.
  myPort = new Serial(this, Serial.list()[13], 9600);

  // read bytes into a buffer until you get a linefeed (ASCII 10):
  myPort.bufferUntil('\n');

  // draw with smooth edges:
  smooth();
  rectMode(CENTER);
}

void draw() {
  background(255);

  // Draw the shape
  rect(xPos, height-10, 30, 10);
  if (shoot) {
    drawShot();
  }
}

void drawShot() {
  if (oneShot) {
    shotPos = height;
    oneShot = false;
  }

  rect(xPos, shotPos, 10, 20);

  shotPos--;
  if ( shotPos == 0) {
    shoot = false; 
    oneShot = true;
  }
}

// serialEvent  method is run automatically by the Processing applet
// whenever the buffer reaches the  byte value set in the bufferUntil()
// method in the setup():

void serialEvent(Serial myPort) {
  // make sure we have a valid byte
  if (myPort == null) {
    return;
  }

  // read the serial buffer:
  String myString = myPort.readStringUntil('\n');
  // if you got any bytes other than the linefeed:
  myString = trim(myString);

  // split the string at the commas
  // and convert the sections into integers:
  int sensors[] = int(split(myString, ','));

  // print out the values you got:
  for (int sensorNum = 0; sensorNum < sensors.length; sensorNum++) {
    print("Sensor " + sensorNum + ": " + sensors[sensorNum] + "\t");
  }
  // add a linefeed after all the sensor values are printed:
  println();
  if (sensors.length > 1) {
    xPos = map(sensors[0], 0, 1023, 15, width-15);
    if (sensors[1] == 255) {
      shoot=true;
    }
  }
  // send a byte to ask for more data:
  myPort.write("A");
}

